/*
 * @brief Blinky example using SysTick and interrupt
 *
 * @note
 * Copyright(C) NXP Semiconductors, 2014
 * All rights reserved.
 *
 * @par
 * Software that is described herein is for illustrative purposes only
 * which provides customers with programming information regarding the
 * LPC products.  This software is supplied "AS IS" without any warranties of
 * any kind, and NXP Semiconductors and its licensor disclaim any and
 * all warranties, express or implied, including all implied warranties of
 * merchantability, fitness for a particular purpose and non-infringement of
 * intellectual property rights.  NXP Semiconductors assumes no responsibility
 * or liability for the use of the software, conveys no license or rights under any
 * patent, copyright, mask work right, or any other intellectual property rights in
 * or to any products. NXP Semiconductors reserves the right to make changes
 * in the software without notification. NXP Semiconductors also makes no
 * representation or warranty that such application will be suitable for the
 * specified use without further testing or modification.
 *
 * @par
 * Permission to use, copy, modify, and distribute this software and its
 * documentation is hereby granted, under NXP Semiconductors' and its
 * licensor's relevant copyrights in the software, without fee, provided that it
 * is used in conjunction with NXP Semiconductors microcontrollers.  This
 * copyright, permission, and disclaimer notice must appear in all copies of
 * this code.
 */

#include "board.h"
#include "sl_protocol.h"
/** @defgroup PERIPH_BLINKY_5410X Simple blinky example
 * @ingroup EXAMPLES_PERIPH_5410X
 * @include "periph\blinky\readme.txt"
 */

/**
 * @}
 */

/*****************************************************************************
 * Private types/enumerations/variables
 ****************************************************************************/

#define TICKRATE_HZ (10)	/* 10 ticks per second */

/*****************************************************************************
 * Public types/enumerations/variables
 ****************************************************************************/

/*****************************************************************************
 * Private functions
 ****************************************************************************/

/*****************************************************************************
 * Public functions
 ****************************************************************************/

/**
 * @brief	Handle interrupt from SysTick timer
 * @return	Nothing
 */
void SysTick_Handler(void)
{
	Board_LED_Toggle(0);
}

/**
 * @brief	main routine for blinky example
 * @return	Function should not exit.
 */
int main(void)
{
	volatile int i;
	SL_PINSETUP_T pinSetup;

	pinSetup.img_type = IMG_AP_WAIT;
	pinSetup.ifSel = SL_I2C2;                                              /* Uses I2C2 as the host interface */
	pinSetup.hostIrqPortPin =  ((0 << 5) + 19);/* Host IRQ on port0 */
	/* hostMisoPortPin, hostMosiPortPin, hostSselPortPin, hostSckPortPin pins do not matter when using I2C */
	pinSetup.hostMisoPortPin = ((0 << 5) + 13);
	pinSetup.hostMosiPortPin = ((0 << 5) + 12);
	pinSetup.hostSselPortPin = ((0 << 5) + 14);
	pinSetup.hostSckPortPin = ((1 << 5) + 3);
	pinSetup.checksum = pinSetup.img_type ^ pinSetup.ifSel ^ pinSetup.hostIrqPortPin ^ pinSetup.hostMisoPortPin ^ pinSetup.hostMosiPortPin ^ pinSetup.hostSselPortPin ^
	                pinSetup.hostSckPortPin;

	SystemCoreClockUpdate();
	Board_Init();
	Board_LED_Set(0, false);
	/* Enable SysTick Timer */
	SysTick_Config(SystemCoreClock / TICKRATE_HZ);
	/*
	* Notice that by default the code to invoke SBL from application is commented out. User needs to enable these lines to
	* test invoking SBL from application functionality.
	*/
#if 0
	for (i=0; i<30000000; i++);

    __disable_irq();
	/* invoke secondary loader from app. Will not return if successful */
		if (bootSecondaryLoader(&pinSetup) == false) {
		                /* Handle error, pin setup table was invalid */
		}
		__enable_irq();
#endif

	while (1) {
		__WFI();
	}

	return 0;
}
